[Lldb-commits] [lldb] r241349 - Remove typedefs for MIchar, MIschar, MIuchar.

Bruce Mitchener bruce.mitchener at gmail.com
Fri Jul 3 06:45:35 PDT 2015


Author: brucem
Date: Fri Jul  3 08:45:34 2015
New Revision: 241349

URL: http://llvm.org/viewvc/llvm-project?rev=241349&view=rev
Log:
Remove typedefs for MIchar, MIschar, MIuchar.

Summary:
This is a start on bringing lldb-mi more in line with the typical
LLDB coding style. This just removes the usage of the typedefs and
doesn't yet clean up any logic or other issues. (This is to keep
the review simple.)

Reviewers: abidh, ki.stfu, domipheus

Subscribers: lldb-commits

Differential Revision: http://reviews.llvm.org/D10917

Modified:
    lldb/trunk/tools/lldb-mi/MICmdArgContext.h
    lldb/trunk/tools/lldb-mi/MICmdArgValFile.cpp
    lldb/trunk/tools/lldb-mi/MICmdArgValString.cpp
    lldb/trunk/tools/lldb-mi/MICmdCmdData.cpp
    lldb/trunk/tools/lldb-mi/MICmdCmdData.h
    lldb/trunk/tools/lldb-mi/MICmdCmdExec.cpp
    lldb/trunk/tools/lldb-mi/MICmdCmdFile.cpp
    lldb/trunk/tools/lldb-mi/MICmdCmdMiscellanous.cpp
    lldb/trunk/tools/lldb-mi/MICmdCmdSymbol.cpp
    lldb/trunk/tools/lldb-mi/MICmdCmdTarget.cpp
    lldb/trunk/tools/lldb-mi/MICmdCmdVar.cpp
    lldb/trunk/tools/lldb-mi/MICmdCmdVar.h
    lldb/trunk/tools/lldb-mi/MICmdInterpreter.cpp
    lldb/trunk/tools/lldb-mi/MICmnLLDBDebugSessionInfo.cpp
    lldb/trunk/tools/lldb-mi/MICmnLLDBDebugSessionInfoVarObj.cpp
    lldb/trunk/tools/lldb-mi/MICmnLLDBDebugSessionInfoVarObj.h
    lldb/trunk/tools/lldb-mi/MICmnLLDBDebugger.cpp
    lldb/trunk/tools/lldb-mi/MICmnLLDBDebuggerHandleEvents.cpp
    lldb/trunk/tools/lldb-mi/MICmnLLDBProxySBValue.cpp
    lldb/trunk/tools/lldb-mi/MICmnLLDBUtilSBValue.cpp
    lldb/trunk/tools/lldb-mi/MICmnLLDBUtilSBValue.h
    lldb/trunk/tools/lldb-mi/MICmnLogMediumFile.cpp
    lldb/trunk/tools/lldb-mi/MICmnLogMediumFile.h
    lldb/trunk/tools/lldb-mi/MICmnMIOutOfBandRecord.cpp
    lldb/trunk/tools/lldb-mi/MICmnMIResultRecord.cpp
    lldb/trunk/tools/lldb-mi/MICmnMIValueConst.cpp
    lldb/trunk/tools/lldb-mi/MICmnMIValueList.cpp
    lldb/trunk/tools/lldb-mi/MICmnMIValueResult.cpp
    lldb/trunk/tools/lldb-mi/MICmnMIValueTuple.cpp
    lldb/trunk/tools/lldb-mi/MICmnResources.cpp
    lldb/trunk/tools/lldb-mi/MICmnResources.h
    lldb/trunk/tools/lldb-mi/MICmnStreamStdin.cpp
    lldb/trunk/tools/lldb-mi/MICmnStreamStdin.h
    lldb/trunk/tools/lldb-mi/MIDataTypes.h
    lldb/trunk/tools/lldb-mi/MIDriver.cpp
    lldb/trunk/tools/lldb-mi/MIDriverMgr.cpp
    lldb/trunk/tools/lldb-mi/MIUtilDateTimeStd.h
    lldb/trunk/tools/lldb-mi/MIUtilFileStd.cpp
    lldb/trunk/tools/lldb-mi/MIUtilFileStd.h
    lldb/trunk/tools/lldb-mi/MIUtilString.cpp
    lldb/trunk/tools/lldb-mi/MIUtilString.h

Modified: lldb/trunk/tools/lldb-mi/MICmdArgContext.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdArgContext.h?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdArgContext.h (original)
+++ lldb/trunk/tools/lldb-mi/MICmdArgContext.h Fri Jul  3 08:45:34 2015
@@ -44,6 +44,6 @@ class CMICmdArgContext
     // Attributes:
   private:
     CMIUtilString m_strCmdArgsAndOptions;
-    const MIchar m_constCharSpace;
+    const char m_constCharSpace;
     const CMIUtilString m_constStrSpace;
 };

Modified: lldb/trunk/tools/lldb-mi/MICmdArgValFile.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdArgValFile.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdArgValFile.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmdArgValFile.cpp Fri Jul  3 08:45:34 2015
@@ -121,7 +121,7 @@ CMICmdArgValFile::GetFileNamePath(const
     CMIUtilString fileNamePath(vrTxt);
 
     // Look for a space in the path
-    const MIchar cSpace = ' ';
+    const char cSpace = ' ';
     const MIint nPos = fileNamePath.find(cSpace);
     if (nPos != (MIint)std::string::npos)
         fileNamePath = CMIUtilString::Format("\"%s\"", fileNamePath.c_str());
@@ -182,10 +182,10 @@ bool
 CMICmdArgValFile::IsValidChars(const CMIUtilString &vrText) const
 {
     static CMIUtilString s_strSpecialCharacters(".'\"`@#$%^&*()_+-={}[]| ");
-    const MIchar *pPtr = const_cast<MIchar *>(vrText.c_str());
+    const char *pPtr = const_cast<char *>(vrText.c_str());
     for (MIuint i = 0; i < vrText.length(); i++, pPtr++)
     {
-        const MIchar c = *pPtr;
+        const char c = *pPtr;
         if (::isalnum((int)c) == 0)
         {
             if (s_strSpecialCharacters.find(c) == CMIUtilString::npos)

Modified: lldb/trunk/tools/lldb-mi/MICmdArgValString.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdArgValString.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdArgValString.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmdArgValString.cpp Fri Jul  3 08:45:34 2015
@@ -179,7 +179,7 @@ CMICmdArgValString::ValidateQuotedText(C
     if (vrwArgContext.RemoveArg(rArg))
     {
         m_bValid = true;
-        const MIchar cQuote = '"';
+        const char cQuote = '"';
         m_argValue = rArg.Trim(cQuote).StripSlashes();
         return MIstatus::success;
     }
@@ -262,7 +262,7 @@ CMICmdArgValString::IsStringArgQuotedTex
         return true;
 
     // CODETAG_QUOTEDTEXT_SIMILAR_CODE
-    const MIchar cQuote = '"';
+    const char cQuote = '"';
     const MIint nPos = vrTxt.find(cQuote);
     if (nPos == (MIint)std::string::npos)
         return false;
@@ -273,8 +273,8 @@ CMICmdArgValString::IsStringArgQuotedTex
 
     // Quote must be the first character in the string or be preceded by a space
     // Also check for embedded string formating quote
-    const MIchar cBckSlash = '\\';
-    const MIchar cSpace = ' ';
+    const char cBckSlash = '\\';
+    const char cSpace = ' ';
     if ((nPos > 1) && (vrTxt[nPos - 1] == cBckSlash) && (vrTxt[nPos - 2] != cSpace))
     {
         return false;
@@ -308,13 +308,13 @@ bool
 CMICmdArgValString::IsStringArgQuotedTextEmbedded(const CMIUtilString &vrTxt) const
 {
     // CODETAG_QUOTEDTEXT_SIMILAR_CODE
-    const MIchar cBckSlash = '\\';
+    const char cBckSlash = '\\';
     const MIint nPos = vrTxt.find(cBckSlash);
     if (nPos == (MIint)std::string::npos)
         return false;
 
     // Slash must be the first character in the string or be preceded by a space
-    const MIchar cSpace = ' ';
+    const char cSpace = ' ';
     if ((nPos > 0) && (vrTxt[nPos - 1] != cSpace))
         return false;
 

Modified: lldb/trunk/tools/lldb-mi/MICmdCmdData.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdCmdData.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdCmdData.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmdCmdData.cpp Fri Jul  3 08:45:34 2015
@@ -265,7 +265,7 @@ CMICmdCmdDataEvaluateExpression::CreateS
 // Throws:  None.
 //--
 bool
-CMICmdCmdDataEvaluateExpression::HaveInvalidCharacterInExpression(const CMIUtilString &vrExpr, MIchar &vrwInvalidChar)
+CMICmdCmdDataEvaluateExpression::HaveInvalidCharacterInExpression(const CMIUtilString &vrExpr, char &vrwInvalidChar)
 {
     static const std::string strInvalidCharacters(";#\\");
     const size_t nInvalidCharacterOffset = vrExpr.find_first_of(strInvalidCharacters);
@@ -403,20 +403,20 @@ CMICmdCmdDataDisassemble::Execute(void)
 
     for (size_t i = 0; i < nInstructions; i++)
     {
-        const MIchar *pUnknown = "??";
+        const char *pUnknown = "??";
         lldb::SBInstruction instrt = instructions.GetInstructionAtIndex(i);
-        const MIchar *pStrMnemonic = instrt.GetMnemonic(sbTarget);
+        const char *pStrMnemonic = instrt.GetMnemonic(sbTarget);
         pStrMnemonic = (pStrMnemonic != nullptr) ? pStrMnemonic : pUnknown;
-        const MIchar *pStrComment = instrt.GetComment(sbTarget);
+        const char *pStrComment = instrt.GetComment(sbTarget);
         CMIUtilString strComment;
         if (pStrComment != nullptr && *pStrComment != '\0')
             strComment = CMIUtilString::Format("; %s", pStrComment);
         lldb::SBAddress address = instrt.GetAddress();
         lldb::addr_t addr = address.GetLoadAddress(sbTarget);
-        const MIchar *pFnName = address.GetFunction().GetName();
+        const char *pFnName = address.GetFunction().GetName();
         pFnName = (pFnName != nullptr) ? pFnName : pUnknown;
         lldb::addr_t addrOffSet = address.GetOffset() - start_offset;
-        const MIchar *pStrOperands = instrt.GetOperands(sbTarget);
+        const char *pStrOperands = instrt.GetOperands(sbTarget);
         pStrOperands = (pStrOperands != nullptr) ? pStrOperands : pUnknown;
         const size_t instrtSize = instrt.GetByteSize();
 
@@ -441,7 +441,7 @@ CMICmdCmdDataDisassemble::Execute(void)
         {
             lldb::SBLineEntry lineEntry = address.GetLineEntry();
             const MIuint nLine = lineEntry.GetLine();
-            const MIchar *pFileName = lineEntry.GetFileSpec().GetFilename();
+            const char *pFileName = lineEntry.GetFileSpec().GetFilename();
             pFileName = (pFileName != nullptr) ? pFileName : pUnknown;
 
             // MI "src_and_asm_line={line=\"%u\",file=\"%s\",line_asm_insn=[ ]}"
@@ -660,7 +660,7 @@ CMICmdCmdDataReadMemoryBytes::Execute(vo
     nAddrStart += nAddrOffset;
     const MIuint64 nAddrNumBytes = pArgNumBytes->GetValue();
 
-    m_pBufferMemory = new MIuchar[nAddrNumBytes];
+    m_pBufferMemory = new unsigned char[nAddrNumBytes];
     if (m_pBufferMemory == nullptr)
     {
         SetError(CMIUtilString::Format(MIRSRC(IDS_CMD_ERR_MEMORY_ALLOC_FAILURE), m_cmdData.strMiCmd.c_str(), nAddrNumBytes));
@@ -1544,13 +1544,13 @@ CMICmdCmdDataWriteMemory::Execute(void)
     m_nCount = pArgNumber->GetValue();
     const MIuint64 nValue = pArgContents->GetValue();
 
-    m_pBufferMemory = new MIuchar[m_nCount];
+    m_pBufferMemory = new unsigned char[m_nCount];
     if (m_pBufferMemory == nullptr)
     {
         SetError(CMIUtilString::Format(MIRSRC(IDS_CMD_ERR_MEMORY_ALLOC_FAILURE), m_cmdData.strMiCmd.c_str(), m_nCount));
         return MIstatus::failure;
     }
-    *m_pBufferMemory = static_cast<MIchar>(nValue);
+    *m_pBufferMemory = static_cast<char>(nValue);
 
     CMICmnLLDBDebugSessionInfo &rSessionInfo(CMICmnLLDBDebugSessionInfo::Instance());
     lldb::SBProcess sbProcess = rSessionInfo.GetProcess();

Modified: lldb/trunk/tools/lldb-mi/MICmdCmdData.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdCmdData.h?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdCmdData.h (original)
+++ lldb/trunk/tools/lldb-mi/MICmdCmdData.h Fri Jul  3 08:45:34 2015
@@ -68,7 +68,7 @@ class CMICmdCmdDataEvaluateExpression :
 
     // Methods:
   private:
-    bool HaveInvalidCharacterInExpression(const CMIUtilString &vrExpr, MIchar &vrwInvalidChar);
+    bool HaveInvalidCharacterInExpression(const CMIUtilString &vrExpr, char &vrwInvalidChar);
 
     // Attributes:
   private:
@@ -78,7 +78,7 @@ class CMICmdCmdDataEvaluateExpression :
     CMICmnMIValueTuple m_miValueTuple;
     bool m_bCompositeVarType; // True = yes composite type, false = internal type
     bool m_bFoundInvalidChar; // True = yes found unexpected character in the expression, false = all ok
-    MIchar m_cExpressionInvalidChar;
+    char m_cExpressionInvalidChar;
     const CMIUtilString m_constStrArgThread; // Not specified in MI spec but Eclipse gives this option. Not handled by command.
     const CMIUtilString m_constStrArgFrame;  // Not specified in MI spec but Eclipse gives this option. Not handled by command.
     const CMIUtilString m_constStrArgExpr;
@@ -155,7 +155,7 @@ class CMICmdCmdDataReadMemoryBytes : pub
     const CMIUtilString m_constStrArgByteOffset;
     const CMIUtilString m_constStrArgAddrExpr;
     const CMIUtilString m_constStrArgNumBytes;
-    MIuchar *m_pBufferMemory;
+    unsigned char *m_pBufferMemory;
     MIuint64 m_nAddrStart;
     MIuint64 m_nAddrNumBytesToRead;
 };
@@ -368,7 +368,7 @@ class CMICmdCmdDataWriteMemory : public
     MIuint64 m_nAddr;
     CMIUtilString m_strContents;
     MIuint64 m_nCount;
-    MIuchar *m_pBufferMemory;
+    unsigned char *m_pBufferMemory;
 };
 
 //++ ============================================================================

Modified: lldb/trunk/tools/lldb-mi/MICmdCmdExec.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdCmdExec.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdCmdExec.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmdCmdExec.cpp Fri Jul  3 08:45:34 2015
@@ -198,7 +198,7 @@ CMICmdCmdExecContinue::~CMICmdCmdExecCon
 bool
 CMICmdCmdExecContinue::Execute(void)
 {
-    const MIchar *pCmd = "continue";
+    const char *pCmd = "continue";
     CMICmnLLDBDebugSessionInfo &rSessionInfo(CMICmnLLDBDebugSessionInfo::Instance());
     const lldb::ReturnStatus rtn = rSessionInfo.GetDebugger().GetCommandInterpreter().HandleCommand(pCmd, m_lldbResult);
     MIunused(rtn);
@@ -217,7 +217,7 @@ CMICmdCmdExecContinue::Execute(void)
     {
         // ToDo: Re-evaluate if this is required when application near finished as this is parsing LLDB error message
         // which seems a hack and is code brittle
-        const MIchar *pLldbErr = m_lldbResult.GetError();
+        const char *pLldbErr = m_lldbResult.GetError();
         const CMIUtilString strLldbMsg(CMIUtilString(pLldbErr).StripCREndOfLine());
         if (strLldbMsg == "error: Process must be launched.")
         {
@@ -367,7 +367,7 @@ CMICmdCmdExecNext::Acknowledge(void)
 {
     if (m_lldbResult.GetErrorSize() > 0)
     {
-        const MIchar *pLldbErr = m_lldbResult.GetError();
+        const char *pLldbErr = m_lldbResult.GetError();
         MIunused(pLldbErr);
         const CMICmnMIValueConst miValueConst(m_lldbResult.GetError());
         const CMICmnMIValueResult miValueResult("message", miValueConst);
@@ -494,7 +494,7 @@ CMICmdCmdExecStep::Acknowledge(void)
 {
     if (m_lldbResult.GetErrorSize() > 0)
     {
-        const MIchar *pLldbErr = m_lldbResult.GetError();
+        const char *pLldbErr = m_lldbResult.GetError();
         MIunused(pLldbErr);
         const CMICmnMIValueConst miValueConst(m_lldbResult.GetError());
         const CMICmnMIValueResult miValueResult("message", miValueConst);
@@ -621,7 +621,7 @@ CMICmdCmdExecNextInstruction::Acknowledg
 {
     if (m_lldbResult.GetErrorSize() > 0)
     {
-        const MIchar *pLldbErr = m_lldbResult.GetError();
+        const char *pLldbErr = m_lldbResult.GetError();
         MIunused(pLldbErr);
         const CMICmnMIValueConst miValueConst(m_lldbResult.GetError());
         const CMICmnMIValueResult miValueResult("message", miValueConst);
@@ -748,7 +748,7 @@ CMICmdCmdExecStepInstruction::Acknowledg
 {
     if (m_lldbResult.GetErrorSize() > 0)
     {
-        const MIchar *pLldbErr = m_lldbResult.GetError();
+        const char *pLldbErr = m_lldbResult.GetError();
         MIunused(pLldbErr);
         const CMICmnMIValueConst miValueConst(m_lldbResult.GetError());
         const CMICmnMIValueResult miValueResult("message", miValueConst);
@@ -876,7 +876,7 @@ CMICmdCmdExecFinish::Acknowledge(void)
 {
     if (m_lldbResult.GetErrorSize() > 0)
     {
-        const MIchar *pLldbErr = m_lldbResult.GetError();
+        const char *pLldbErr = m_lldbResult.GetError();
         MIunused(pLldbErr);
         const CMICmnMIValueConst miValueConst(m_lldbResult.GetError());
         const CMICmnMIValueResult miValueResult("message", miValueConst);

Modified: lldb/trunk/tools/lldb-mi/MICmdCmdFile.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdCmdFile.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdCmdFile.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmdCmdFile.cpp Fri Jul  3 08:45:34 2015
@@ -106,8 +106,8 @@ CMICmdCmdFileExecAndSymbols::Execute(voi
     CMICmnLLDBDebugSessionInfo &rSessionInfo(CMICmnLLDBDebugSessionInfo::Instance());
     lldb::SBDebugger &rDbgr = rSessionInfo.GetDebugger();
     lldb::SBError error;
-    const MIchar *pTargetTriple = nullptr; // Let LLDB discover the triple required
-    const MIchar *pTargetPlatformName = platformName.c_str();
+    const char *pTargetTriple = nullptr; // Let LLDB discover the triple required
+    const char *pTargetPlatformName = platformName.c_str();
     const bool bAddDepModules = false;
     lldb::SBTarget target = rDbgr.CreateTarget(strExeFilePath.c_str(), pTargetTriple, pTargetPlatformName, bAddDepModules, error);
     CMIUtilString strWkDir;

Modified: lldb/trunk/tools/lldb-mi/MICmdCmdMiscellanous.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdCmdMiscellanous.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdCmdMiscellanous.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmdCmdMiscellanous.cpp Fri Jul  3 08:45:34 2015
@@ -330,8 +330,8 @@ CMICmdCmdListThreadGroups::Acknowledge(v
         if (rSessionInfo.GetTarget().IsValid())
         {
             lldb::SBTarget sbTrgt = rSessionInfo.GetTarget();
-            const MIchar *pDir = sbTrgt.GetExecutable().GetDirectory();
-            const MIchar *pFileName = sbTrgt.GetExecutable().GetFilename();
+            const char *pDir = sbTrgt.GetExecutable().GetDirectory();
+            const char *pFileName = sbTrgt.GetExecutable().GetFilename();
             const CMIUtilString strFile(CMIUtilString::Format("%s/%s", pDir, pFileName));
             const CMICmnMIValueConst miValueConst4(strFile);
             const CMICmnMIValueResult miValueResult4("executable", miValueConst4);

Modified: lldb/trunk/tools/lldb-mi/MICmdCmdSymbol.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdCmdSymbol.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdCmdSymbol.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmdCmdSymbol.cpp Fri Jul  3 08:45:34 2015
@@ -104,7 +104,7 @@ CMICmdCmdSymbolListLines::Acknowledge(vo
 {
     if (m_lldbResult.GetErrorSize() > 0)
     {
-        const MIchar *pLldbErr = m_lldbResult.GetError();
+        const char *pLldbErr = m_lldbResult.GetError();
         const CMIUtilString strMsg(CMIUtilString(pLldbErr).StripCRAll());
         const CMICmnMIValueConst miValueConst(strMsg);
         const CMICmnMIValueResult miValueResult("message", miValueConst);

Modified: lldb/trunk/tools/lldb-mi/MICmdCmdTarget.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdCmdTarget.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdCmdTarget.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmdCmdTarget.cpp Fri Jul  3 08:45:34 2015
@@ -111,7 +111,7 @@ CMICmdCmdTargetSelect::Execute(void)
     const CMIUtilString strUrl = CMIUtilString::Format("connect://%s", pArgParameters->GetValue().c_str());
 
     // Ask LLDB to collect to the target port
-    const MIchar *pPlugin("gdb-remote");
+    const char *pPlugin("gdb-remote");
     lldb::SBError error;
     lldb::SBProcess process = rSessionInfo.GetTarget().ConnectRemote(rSessionInfo.GetListener(), strUrl.c_str(), pPlugin, error);
 

Modified: lldb/trunk/tools/lldb-mi/MICmdCmdVar.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdCmdVar.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdCmdVar.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmdCmdVar.cpp Fri Jul  3 08:45:34 2015
@@ -461,7 +461,7 @@ CMICmdCmdVarUpdate::CreateSelf(void)
 // Throws:  None.
 //--
 bool
-CMICmdCmdVarUpdate::MIFormResponse(const CMIUtilString &vrStrVarName, const MIchar *const vpValue, const CMIUtilString &vrStrScope)
+CMICmdCmdVarUpdate::MIFormResponse(const CMIUtilString &vrStrVarName, const char *const vpValue, const CMIUtilString &vrStrScope)
 {
     // MI print "[{name=\"%s\",value=\"%s\",in_scope=\"%s\",type_changed=\"false\",has_more=\"0\"}]"
     const CMICmnMIValueConst miValueConst(vrStrVarName);
@@ -1335,7 +1335,7 @@ CMICmdCmdVarInfoPathExpression::Execute(
         return MIstatus::failure;
     }
 
-    const MIchar *pPathExpression = stream.GetData();
+    const char *pPathExpression = stream.GetData();
     if (pPathExpression == nullptr)
     {
         // Build expression from what we do know

Modified: lldb/trunk/tools/lldb-mi/MICmdCmdVar.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdCmdVar.h?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdCmdVar.h (original)
+++ lldb/trunk/tools/lldb-mi/MICmdCmdVar.h Fri Jul  3 08:45:34 2015
@@ -122,7 +122,7 @@ class CMICmdCmdVarUpdate : public CMICmd
     // Methods:
   private:
     bool ExamineSBValueForChange(lldb::SBValue &vrwValue, bool &vrwbChanged);
-    bool MIFormResponse(const CMIUtilString &vrStrVarName, const MIchar *const vpValue, const CMIUtilString &vrStrScope);
+    bool MIFormResponse(const CMIUtilString &vrStrVarName, const char *const vpValue, const CMIUtilString &vrStrScope);
 
     // Attribute:
   private:

Modified: lldb/trunk/tools/lldb-mi/MICmdInterpreter.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdInterpreter.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdInterpreter.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmdInterpreter.cpp Fri Jul  3 08:45:34 2015
@@ -186,7 +186,7 @@ CMICmdInterpreter::MiHasCmdTokenEndingHy
 bool
 CMICmdInterpreter::MiHasCmdTokenEndingAlpha(const CMIUtilString &vTextLine)
 {
-    MIchar cChar = vTextLine[0];
+    char cChar = vTextLine[0];
     MIuint i = 0;
     while (::isdigit(cChar) != 0)
     {

Modified: lldb/trunk/tools/lldb-mi/MICmnLLDBDebugSessionInfo.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnLLDBDebugSessionInfo.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnLLDBDebugSessionInfo.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnLLDBDebugSessionInfo.cpp Fri Jul  3 08:45:34 2015
@@ -380,11 +380,11 @@ CMICmnLLDBDebugSessionInfo::MIResponseFo
         return MIstatus::failure;
 
     // Add "target-id"
-    const MIchar *pThreadName = rThread.GetName();
+    const char *pThreadName = rThread.GetName();
     const MIuint len = (pThreadName != nullptr) ? CMIUtilString(pThreadName).length() : 0;
     const bool bHaveName = ((pThreadName != nullptr) && (len > 0) && (len < 32) &&
                             CMIUtilString::IsAllValidAlphaAndNumeric(pThreadName)); // 32 is arbitary number
-    const MIchar *pThrdFmt = bHaveName ? "%s" : "Thread %d";
+    const char *pThrdFmt = bHaveName ? "%s" : "Thread %d";
     CMIUtilString strThread;
     if (bHaveName)
         strThread = CMIUtilString::Format(pThrdFmt, pThreadName);
@@ -635,17 +635,17 @@ CMICmnLLDBDebugSessionInfo::GetFrameInfo
     const MIuint nBytes = rFrame.GetLineEntry().GetFileSpec().GetPath(&pBuffer[0], sizeof(pBuffer));
     MIunused(nBytes);
     CMIUtilString strResolvedPath(&pBuffer[0]);
-    const MIchar *pUnkwn = "??";
+    const char *pUnkwn = "??";
     if (!ResolvePath(pUnkwn, strResolvedPath))
         return MIstatus::failure;
     vwPath = strResolvedPath;
 
     vwPc = rFrame.GetPC();
 
-    const MIchar *pFnName = rFrame.GetFunctionName();
+    const char *pFnName = rFrame.GetFunctionName();
     vwFnName = (pFnName != nullptr) ? pFnName : pUnkwn;
 
-    const MIchar *pFileName = rFrame.GetLineEntry().GetFileSpec().GetFilename();
+    const char *pFileName = rFrame.GetLineEntry().GetFileSpec().GetFilename();
     vwFileName = (pFileName != nullptr) ? pFileName : pUnkwn;
 
     vwnLine = rFrame.GetLineEntry().GetLine();
@@ -801,13 +801,13 @@ CMICmnLLDBDebugSessionInfo::GetBrkPtInfo
     lldb::SBBreakpointLocation brkPtLoc = rBrkPt.GetLocationAtIndex(0);
     lldb::SBAddress brkPtAddr = brkPtLoc.GetAddress();
     lldb::SBSymbolContext symbolCntxt = brkPtAddr.GetSymbolContext(lldb::eSymbolContextEverything);
-    const MIchar *pUnkwn = "??";
+    const char *pUnkwn = "??";
     lldb::SBModule rModule = symbolCntxt.GetModule();
-    const MIchar *pModule = rModule.IsValid() ? rModule.GetFileSpec().GetFilename() : pUnkwn;
+    const char *pModule = rModule.IsValid() ? rModule.GetFileSpec().GetFilename() : pUnkwn;
     MIunused(pModule);
-    const MIchar *pFile = pUnkwn;
-    const MIchar *pFn = pUnkwn;
-    const MIchar *pFilePath = pUnkwn;
+    const char *pFile = pUnkwn;
+    const char *pFn = pUnkwn;
+    const char *pFilePath = pUnkwn;
     size_t nLine = 0;
     lldb::addr_t nAddr = brkPtAddr.GetLoadAddress(GetTarget());
     if (nAddr == LLDB_INVALID_ADDRESS)

Modified: lldb/trunk/tools/lldb-mi/MICmnLLDBDebugSessionInfoVarObj.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnLLDBDebugSessionInfoVarObj.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnLLDBDebugSessionInfoVarObj.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnLLDBDebugSessionInfoVarObj.cpp Fri Jul  3 08:45:34 2015
@@ -13,11 +13,11 @@
 #include "MICmnLLDBUtilSBValue.h"
 
 // Instantiations:
-const MIchar *CMICmnLLDBDebugSessionInfoVarObj::ms_aVarFormatStrings[] = {
+const char *CMICmnLLDBDebugSessionInfoVarObj::ms_aVarFormatStrings[] = {
     // CODETAG_SESSIONINFO_VARFORMAT_ENUM
     // *** Order is import here.
     "<Invalid var format>", "binary", "octal", "decimal", "hexadecimal", "natural"};
-const MIchar *CMICmnLLDBDebugSessionInfoVarObj::ms_aVarFormatChars[] = {
+const char *CMICmnLLDBDebugSessionInfoVarObj::ms_aVarFormatChars[] = {
     // CODETAG_SESSIONINFO_VARFORMAT_ENUM
     // *** Order is import here.
     "<Invalid var format>", "t", "o", "d", "x", "N"};
@@ -223,7 +223,7 @@ CMICmnLLDBDebugSessionInfoVarObj::GetVar
     // CODETAG_SESSIONINFO_VARFORMAT_ENUM
     for (MIuint i = 0; i < eVarFormat_count; i++)
     {
-        const MIchar *pVarFormatString = ms_aVarFormatStrings[i];
+        const char *pVarFormatString = ms_aVarFormatStrings[i];
         if (vrStrFormat == pVarFormatString)
             return static_cast<varFormat_e>(i);
     }
@@ -240,7 +240,7 @@ CMICmnLLDBDebugSessionInfoVarObj::GetVar
 // Throws:  None.
 //--
 CMICmnLLDBDebugSessionInfoVarObj::varFormat_e
-CMICmnLLDBDebugSessionInfoVarObj::GetVarFormatForChar(const MIchar &vrcFormat)
+CMICmnLLDBDebugSessionInfoVarObj::GetVarFormatForChar(const char &vrcFormat)
 {
     if ('r' == vrcFormat)
         return eVarFormat_Hex;
@@ -248,7 +248,7 @@ CMICmnLLDBDebugSessionInfoVarObj::GetVar
     // CODETAG_SESSIONINFO_VARFORMAT_ENUM
     for (MIuint i = 0; i < eVarFormat_count; i++)
     {
-        const MIchar *pVarFormatChar = ms_aVarFormatChars[i];
+        const char *pVarFormatChar = ms_aVarFormatChars[i];
         if (*pVarFormatChar == vrcFormat)
             return static_cast<varFormat_e>(i);
     }
@@ -298,7 +298,7 @@ CMICmnLLDBDebugSessionInfoVarObj::GetVal
 // Throws:  None.
 //--
 CMIUtilString
-CMICmnLLDBDebugSessionInfoVarObj::GetStringFormatted(const MIuint64 vnValue, const MIchar *vpStrValueNatural,
+CMICmnLLDBDebugSessionInfoVarObj::GetStringFormatted(const MIuint64 vnValue, const char *vpStrValueNatural,
                                                      const CMICmnLLDBDebugSessionInfoVarObj::varFormat_e veVarFormat)
 {
     CMIUtilString strFormattedValue;

Modified: lldb/trunk/tools/lldb-mi/MICmnLLDBDebugSessionInfoVarObj.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnLLDBDebugSessionInfoVarObj.h?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnLLDBDebugSessionInfoVarObj.h (original)
+++ lldb/trunk/tools/lldb-mi/MICmnLLDBDebugSessionInfoVarObj.h Fri Jul  3 08:45:34 2015
@@ -57,7 +57,7 @@ class CMICmnLLDBDebugSessionInfoVarObj
     // Statics:
   public:
     static varFormat_e GetVarFormatForString(const CMIUtilString &vrStrFormat);
-    static varFormat_e GetVarFormatForChar(const MIchar &vrcFormat);
+    static varFormat_e GetVarFormatForChar(const char &vrcFormat);
     static CMIUtilString GetValueStringFormatted(const lldb::SBValue &vrValue, const varFormat_e veVarFormat);
     static void VarObjAdd(const CMICmnLLDBDebugSessionInfoVarObj &vrVarObj);
     static void VarObjDelete(const CMIUtilString &vrVarName);
@@ -105,7 +105,7 @@ class CMICmnLLDBDebugSessionInfoVarObj
 
     // Statics:
   private:
-    static CMIUtilString GetStringFormatted(const MIuint64 vnValue, const MIchar *vpStrValueNatural, varFormat_e veVarFormat);
+    static CMIUtilString GetStringFormatted(const MIuint64 vnValue, const char *vpStrValueNatural, varFormat_e veVarFormat);
 
     // Methods:
   private:
@@ -114,8 +114,8 @@ class CMICmnLLDBDebugSessionInfoVarObj
 
     // Attributes:
   private:
-    static const MIchar *ms_aVarFormatStrings[];
-    static const MIchar *ms_aVarFormatChars[];
+    static const char *ms_aVarFormatStrings[];
+    static const char *ms_aVarFormatChars[];
     static MapKeyToVarObj_t ms_mapVarIdToVarObj;
     static MIuint ms_nVarUniqueId;
     static varFormat_e ms_eDefaultFormat;    // overrides "natural" format

Modified: lldb/trunk/tools/lldb-mi/MICmnLLDBDebugger.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnLLDBDebugger.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnLLDBDebugger.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnLLDBDebugger.cpp Fri Jul  3 08:45:34 2015
@@ -393,7 +393,7 @@ CMICmnLLDBDebugger::RegisterForEvent(con
     if (!ClientSaveMask(vClientName, vBroadcasterClass, vEventMask))
         return MIstatus::failure;
 
-    const MIchar *pBroadCasterName = vBroadcasterClass.c_str();
+    const char *pBroadCasterName = vBroadcasterClass.c_str();
     MIuint eventMask = vEventMask;
     eventMask += existingMask;
     const MIuint result = m_lldbListener.StartListeningForEventClass(m_lldbDebugger, pBroadCasterName, eventMask);
@@ -420,7 +420,7 @@ CMICmnLLDBDebugger::RegisterForEvent(con
 bool
 CMICmnLLDBDebugger::RegisterForEvent(const CMIUtilString &vClientName, const lldb::SBBroadcaster &vBroadcaster, const MIuint vEventMask)
 {
-    const MIchar *pBroadcasterName = vBroadcaster.GetName();
+    const char *pBroadcasterName = vBroadcaster.GetName();
     if (pBroadcasterName == nullptr)
     {
         SetErrorDescription(CMIUtilString::Format(MIRSRC(IDS_LLDBDEBUGGER_ERR_BROARDCASTER_NAME), MIRSRC(IDS_WORD_INVALIDNULLPTR)));
@@ -485,7 +485,7 @@ CMICmnLLDBDebugger::UnregisterForEvent(c
         }
     }
 
-    const MIchar *pBroadCasterName = vBroadcasterClass.c_str();
+    const char *pBroadCasterName = vBroadcasterClass.c_str();
     if (!m_lldbListener.StopListeningForEventClass(m_lldbDebugger, pBroadCasterName, newEventMask))
     {
         SetErrorDescription(CMIUtilString::Format(MIRSRC(IDS_LLDBDEBUGGER_ERR_STOPLISTENER), vClientName.c_str(), pBroadCasterName));

Modified: lldb/trunk/tools/lldb-mi/MICmnLLDBDebuggerHandleEvents.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnLLDBDebuggerHandleEvents.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnLLDBDebuggerHandleEvents.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnLLDBDebuggerHandleEvents.cpp Fri Jul  3 08:45:34 2015
@@ -169,7 +169,7 @@ CMICmnLLDBDebuggerHandleEvents::HandleEv
 {
     bool bOk = MIstatus::success;
 
-    const MIchar *pEventType = "";
+    const char *pEventType = "";
     const MIuint nEventType = vEvent.GetType();
     switch (nEventType)
     {
@@ -216,7 +216,7 @@ CMICmnLLDBDebuggerHandleEvents::HandleEv
 {
     bool bOk = MIstatus::success;
 
-    const MIchar *pEventType = "";
+    const char *pEventType = "";
     const lldb::BreakpointEventType eEvent = lldb::SBBreakpoint::GetBreakpointEventTypeFromEvent(vEvent);
     switch (eEvent)
     {
@@ -418,7 +418,7 @@ CMICmnLLDBDebuggerHandleEvents::HandleEv
         sBrkPtInfo.m_strOrigLoc = CMIUtilString::Format("%s:%d", sBrkPtInfo.m_fileName.c_str(), sBrkPtInfo.m_nLine);
         sBrkPtInfo.m_nIgnore = brkPt.GetIgnoreCount();
         sBrkPtInfo.m_bPending = false;
-        const MIchar *pStrCondition = brkPt.GetCondition();
+        const char *pStrCondition = brkPt.GetCondition();
         sBrkPtInfo.m_bCondition = (pStrCondition != nullptr) ? true : false;
         sBrkPtInfo.m_strCondition = (pStrCondition != nullptr) ? pStrCondition : "??";
         sBrkPtInfo.m_bBrkPtThreadId = (brkPt.GetThreadID() != 0) ? true : false;
@@ -482,7 +482,7 @@ CMICmnLLDBDebuggerHandleEvents::HandleEv
         return MIstatus::failure;
 
     bool bOk = MIstatus::success;
-    const MIchar *pEventType = "";
+    const char *pEventType = "";
     const MIuint nEventType = vEvent.GetType();
     switch (nEventType)
     {
@@ -584,7 +584,7 @@ CMICmnLLDBDebuggerHandleEvents::HandleEv
         return MIstatus::failure;
 
     bool bOk = MIstatus::success;
-    const MIchar *pEventType = "";
+    const char *pEventType = "";
     const MIuint nEventType = vEvent.GetType();
     switch (nEventType)
     {
@@ -749,7 +749,7 @@ CMICmnLLDBDebuggerHandleEvents::HandleEv
     // This function is not used
     // *** This function is under development
 
-    const MIchar *pEventType = "";
+    const char *pEventType = "";
     const MIuint nEventType = vEvent.GetType();
     switch (nEventType)
     {
@@ -829,7 +829,7 @@ CMICmnLLDBDebuggerHandleEvents::HandlePr
     }
 
     bool bShouldBrk = true;
-    const MIchar *pEventType = "";
+    const char *pEventType = "";
     switch (eEventState)
     {
         case lldb::eStateUnloaded:
@@ -940,7 +940,7 @@ CMICmnLLDBDebuggerHandleEvents::HandlePr
     if (!UpdateSelectedThread())
         return MIstatus::failure;
 
-    const MIchar *pEventType = "";
+    const char *pEventType = "";
     bool bOk = MIstatus::success;
     lldb::SBProcess sbProcess = CMICmnLLDBDebugSessionInfo::Instance().GetProcess();
     const lldb::StopReason eStoppedReason = sbProcess.GetSelectedThread().GetStopReason();
@@ -1114,7 +1114,7 @@ CMICmnLLDBDebuggerHandleEvents::HandlePr
         const CMICmnMIValueResult miValueResult("reason", miValueConst);
         CMICmnMIOutOfBandRecord miOutOfBandRecord(CMICmnMIOutOfBandRecord::eOutOfBand_Stopped, miValueResult);
         lldb::SBUnixSignals sbUnixSignals = sbProcess.GetUnixSignals();
-        const MIchar *pSignal = sbUnixSignals.GetSignalAsCString(nStopReason);
+        const char *pSignal = sbUnixSignals.GetSignalAsCString(nStopReason);
         if (pSignal)
         {
             const CMICmnMIValueConst miValueConst2(pSignal);

Modified: lldb/trunk/tools/lldb-mi/MICmnLLDBProxySBValue.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnLLDBProxySBValue.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnLLDBProxySBValue.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnLLDBProxySBValue.cpp Fri Jul  3 08:45:34 2015
@@ -103,11 +103,11 @@ bool
 CMICmnLLDBProxySBValue::GetCString(const lldb::SBValue &vrValue, CMIUtilString &vwCString)
 {
     lldb::SBValue &rValue = const_cast<lldb::SBValue &>(vrValue);
-    const MIchar *pCType = rValue.GetTypeName();
+    const char *pCType = rValue.GetTypeName();
     if (pCType == nullptr)
         return MIstatus::failure;
 
-    const MIchar *pType = "unsigned char *";
+    const char *pType = "unsigned char *";
     if (!CMIUtilString::Compare(pCType, pType))
         return MIstatus::failure;
 
@@ -120,7 +120,7 @@ CMICmnLLDBProxySBValue::GetCString(const
     lldb::SBProcess sbProcess = rSessionInfo.GetProcess();
     MIuint nBufferSize = 64;
     bool bNeedResize = false;
-    MIchar *pBuffer = static_cast<MIchar *>(::malloc(nBufferSize));
+    char *pBuffer = static_cast<char *>(::malloc(nBufferSize));
     do
     {
         lldb::SBError error;
@@ -129,7 +129,7 @@ CMICmnLLDBProxySBValue::GetCString(const
         {
             bNeedResize = true;
             nBufferSize = nBufferSize << 1;
-            pBuffer = static_cast<MIchar *>(::realloc(pBuffer, nBufferSize));
+            pBuffer = static_cast<char *>(::realloc(pBuffer, nBufferSize));
         }
         else
             bNeedResize = false;

Modified: lldb/trunk/tools/lldb-mi/MICmnLLDBUtilSBValue.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnLLDBUtilSBValue.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnLLDBUtilSBValue.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnLLDBUtilSBValue.cpp Fri Jul  3 08:45:34 2015
@@ -59,7 +59,7 @@ CMICmnLLDBUtilSBValue::~CMICmnLLDBUtilSB
 CMIUtilString
 CMICmnLLDBUtilSBValue::GetName(void) const
 {
-    const MIchar *pName = m_bValidSBValue ? m_rValue.GetName() : nullptr;
+    const char *pName = m_bValidSBValue ? m_rValue.GetName() : nullptr;
     const CMIUtilString text((pName != nullptr) ? pName : m_pUnkwn);
 
     return text;
@@ -129,7 +129,7 @@ CMICmnLLDBUtilSBValue::GetSimpleValue(co
         }
         else
         {
-            const MIchar *pValue = m_rValue.GetValue();
+            const char *pValue = m_rValue.GetValue();
             vwrValue = pValue != nullptr ? pValue : m_pUnkwn;
             return MIstatus::success;
         }
@@ -143,7 +143,7 @@ CMICmnLLDBUtilSBValue::GetSimpleValue(co
         }
         else
         {
-            const MIchar *pValue = m_rValue.GetValue();
+            const char *pValue = m_rValue.GetValue();
             vwrValue = pValue != nullptr ? pValue : m_pUnkwn;
             return MIstatus::success;
         }
@@ -223,7 +223,7 @@ CMICmnLLDBUtilSBValue::GetSimpleValueCha
 CMIUtilString
 CMICmnLLDBUtilSBValue::GetSimpleValueCStringPointer(void) const
 {
-    const MIchar *value = m_rValue.GetValue();
+    const char *value = m_rValue.GetValue();
     if (value == nullptr)
         return m_pUnkwn;
 
@@ -521,7 +521,7 @@ CMICmnLLDBUtilSBValue::IsValueUnknown(vo
 CMIUtilString
 CMICmnLLDBUtilSBValue::GetTypeName(void) const
 {
-    const MIchar *pName = m_bValidSBValue ? m_rValue.GetTypeName() : nullptr;
+    const char *pName = m_bValidSBValue ? m_rValue.GetTypeName() : nullptr;
     const CMIUtilString text((pName != nullptr) ? pName : m_pUnkwn);
 
     return text;
@@ -537,7 +537,7 @@ CMICmnLLDBUtilSBValue::GetTypeName(void)
 CMIUtilString
 CMICmnLLDBUtilSBValue::GetTypeNameDisplay(void) const
 {
-    const MIchar *pName = m_bValidSBValue ? m_rValue.GetDisplayTypeName() : nullptr;
+    const char *pName = m_bValidSBValue ? m_rValue.GetDisplayTypeName() : nullptr;
     const CMIUtilString text((pName != nullptr) ? pName : m_pUnkwn);
 
     return text;
@@ -569,7 +569,7 @@ CMICmnLLDBUtilSBValue::HasName(void) con
 {
     bool bHasAName = false;
 
-    const MIchar *pName = m_bValidSBValue ? m_rValue.GetDisplayTypeName() : nullptr;
+    const char *pName = m_bValidSBValue ? m_rValue.GetDisplayTypeName() : nullptr;
     if (pName != nullptr)
     {
         bHasAName = (CMIUtilString(pName).length() > 0);

Modified: lldb/trunk/tools/lldb-mi/MICmnLLDBUtilSBValue.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnLLDBUtilSBValue.h?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnLLDBUtilSBValue.h (original)
+++ lldb/trunk/tools/lldb-mi/MICmnLLDBUtilSBValue.h Fri Jul  3 08:45:34 2015
@@ -61,8 +61,8 @@ class CMICmnLLDBUtilSBValue
     // Attributes:
   private:
     lldb::SBValue &m_rValue;
-    const MIchar *m_pUnkwn;
-    const MIchar *m_pComposite;
+    const char *m_pUnkwn;
+    const char *m_pComposite;
     bool m_bValidSBValue;    // True = SBValue is a valid object, false = not valid.
     bool m_bHandleCharType;  // True = Yes return text molding to char type, false = just return data.
     bool m_bHandleArrayType; // True = Yes return special stub for array type, false = just return data.

Modified: lldb/trunk/tools/lldb-mi/MICmnLogMediumFile.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnLogMediumFile.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnLogMediumFile.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnLogMediumFile.cpp Fri Jul  3 08:45:34 2015
@@ -276,7 +276,7 @@ CMICmnLogMediumFile::MassagedData(const
 {
     const CMIUtilString strCr("\n");
     CMIUtilString data;
-    const MIchar verbosityCode(ConvertLogVerbosityTypeToId(veType));
+    const char verbosityCode(ConvertLogVerbosityTypeToId(veType));
     const CMIUtilString dt(CMIUtilString::Format("%s %s", m_strDate.c_str(), m_dateTime.GetTime().c_str()));
 
     data = CMIUtilString::Format("%c,%s,%s", verbosityCode, dt.c_str(), vData.c_str());
@@ -300,10 +300,10 @@ CMICmnLogMediumFile::MassagedData(const
 // Return:  wchar_t - A letter.
 // Throws:  None.
 //--
-MIchar
+char
 CMICmnLogMediumFile::ConvertLogVerbosityTypeToId(const CMICmnLog::ELogVerbosity veType) const
 {
-    MIchar c = 0;
+    char c = 0;
     if (veType != 0)
     {
         MIuint cnt = 0;

Modified: lldb/trunk/tools/lldb-mi/MICmnLogMediumFile.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnLogMediumFile.h?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnLogMediumFile.h (original)
+++ lldb/trunk/tools/lldb-mi/MICmnLogMediumFile.h Fri Jul  3 08:45:34 2015
@@ -66,7 +66,7 @@ class CMICmnLogMediumFile : public CMICm
     bool FileFormFileNamePath(void);
     CMIUtilString MassagedData(const CMIUtilString &vData, const CMICmnLog::ELogVerbosity veType);
     bool FileWriteHeader(void);
-    MIchar ConvertLogVerbosityTypeToId(const CMICmnLog::ELogVerbosity veType) const;
+    char ConvertLogVerbosityTypeToId(const CMICmnLog::ELogVerbosity veType) const;
     CMIUtilString ConvertCr(const CMIUtilString &vData) const;
 
     // Attributes:

Modified: lldb/trunk/tools/lldb-mi/MICmnMIOutOfBandRecord.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnMIOutOfBandRecord.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnMIOutOfBandRecord.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnMIOutOfBandRecord.cpp Fri Jul  3 08:45:34 2015
@@ -143,7 +143,7 @@ CMICmnMIOutOfBandRecord::GetString(void)
 bool
 CMICmnMIOutOfBandRecord::BuildAsyncRecord(void)
 {
-    const MIchar *pFormat = "%s%s";
+    const char *pFormat = "%s%s";
     const CMIUtilString &rStrAsyncRecord(ms_MapOutOfBandToOutOfBandText[m_eResultAsyncRecordClass]);
     const CMIUtilString &rStrToken(ms_constMapAsyncRecordTextToToken[m_eResultAsyncRecordClass]);
     m_strAsyncRecord = CMIUtilString::Format(pFormat, rStrToken.c_str(), rStrAsyncRecord.c_str());

Modified: lldb/trunk/tools/lldb-mi/MICmnMIResultRecord.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnMIResultRecord.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnMIResultRecord.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnMIResultRecord.cpp Fri Jul  3 08:45:34 2015
@@ -106,7 +106,7 @@ CMICmnMIResultRecord::GetString(void) co
 bool
 CMICmnMIResultRecord::BuildResultRecord(void)
 {
-    const MIchar *pFormat = "%s%s%s";
+    const char *pFormat = "%s%s%s";
     const CMIUtilString &rStrResultRecord(ms_MapResultClassToResultClassText[m_eResultRecordResultClass]);
     m_strResultRecord =
         CMIUtilString::Format(pFormat, m_strResultRecordToken.c_str(), ms_constStrResultRecordHat.c_str(), rStrResultRecord.c_str());

Modified: lldb/trunk/tools/lldb-mi/MICmnMIValueConst.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnMIValueConst.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnMIValueConst.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnMIValueConst.cpp Fri Jul  3 08:45:34 2015
@@ -73,13 +73,13 @@ CMICmnMIValueConst::BuildConst(void)
         }
         else
         {
-            const MIchar *pFormat = "%s%s%s";
+            const char *pFormat = "%s%s%s";
             m_strValue = CMIUtilString::Format(pFormat, ms_constStrDblQuote.c_str(), strValue.c_str(), ms_constStrDblQuote.c_str());
         }
     }
     else
     {
-        const MIchar *pFormat = "%s%s";
+        const char *pFormat = "%s%s";
         m_strValue = CMIUtilString::Format(pFormat, ms_constStrDblQuote.c_str(), ms_constStrDblQuote.c_str());
     }
 

Modified: lldb/trunk/tools/lldb-mi/MICmnMIValueList.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnMIValueList.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnMIValueList.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnMIValueList.cpp Fri Jul  3 08:45:34 2015
@@ -76,7 +76,7 @@ CMICmnMIValueList::~CMICmnMIValueList(vo
 bool
 CMICmnMIValueList::BuildList(void)
 {
-    const MIchar *pFormat = "[%s]";
+    const char *pFormat = "[%s]";
     m_strValue = CMIUtilString::Format(pFormat, m_strValue.c_str());
 
     return MIstatus::success;
@@ -136,7 +136,7 @@ CMICmnMIValueList::BuildList(const CMICm
     }
 
     const CMIUtilString data(ExtractContentNoBrackets());
-    const MIchar *pFormat = "[%s,%s]";
+    const char *pFormat = "[%s,%s]";
     m_strValue = CMIUtilString::Format(pFormat, data.c_str(), vResult.GetString().c_str());
 
     return MIstatus::success;
@@ -168,7 +168,7 @@ CMICmnMIValueList::BuildList(const CMICm
     size_t len = m_strValue.size();
     if ( (len > 1) && (m_strValue[0] == '[') && (m_strValue[len - 1] == ']') )
         m_strValue = m_strValue.substr(1, len - 2);
-    const MIchar *pFormat = "[%s,%s]";
+    const char *pFormat = "[%s,%s]";
     m_strValue = CMIUtilString::Format(pFormat, m_strValue.c_str(), vValue.GetString().c_str());
 
     return MIstatus::success;

Modified: lldb/trunk/tools/lldb-mi/MICmnMIValueResult.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnMIValueResult.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnMIValueResult.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnMIValueResult.cpp Fri Jul  3 08:45:34 2015
@@ -83,7 +83,7 @@ CMICmnMIValueResult::~CMICmnMIValueResul
 bool
 CMICmnMIValueResult::BuildResult(void)
 {
-    const MIchar *pFormat = m_bUseSpacing ? "%s %s %s" : "%s%s%s";
+    const char *pFormat = m_bUseSpacing ? "%s %s %s" : "%s%s%s";
     m_strValue = CMIUtilString::Format(pFormat, m_strPartVariable.c_str(), ms_constStrEqual.c_str(), m_partMIValue.GetString().c_str());
 
     return MIstatus::success;
@@ -101,7 +101,7 @@ CMICmnMIValueResult::BuildResult(void)
 bool
 CMICmnMIValueResult::BuildResult(const CMIUtilString &vVariable, const CMICmnMIValue &vValue)
 {
-    const MIchar *pFormat = m_bUseSpacing ? "%s, %s %s %s" : "%s,%s%s%s";
+    const char *pFormat = m_bUseSpacing ? "%s, %s %s %s" : "%s,%s%s%s";
     m_strValue =
         CMIUtilString::Format(pFormat, m_strValue.c_str(), vVariable.c_str(), ms_constStrEqual.c_str(), vValue.GetString().c_str());
 

Modified: lldb/trunk/tools/lldb-mi/MICmnMIValueTuple.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnMIValueTuple.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnMIValueTuple.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnMIValueTuple.cpp Fri Jul  3 08:45:34 2015
@@ -76,7 +76,7 @@ CMICmnMIValueTuple::~CMICmnMIValueTuple(
 bool
 CMICmnMIValueTuple::BuildTuple(void)
 {
-    const MIchar *pFormat = "{%s}";
+    const char *pFormat = "{%s}";
     m_strValue = CMIUtilString::Format(pFormat, m_strValue.c_str());
 
     return MIstatus::success;
@@ -110,7 +110,7 @@ CMICmnMIValueTuple::BuildTuple(const CMI
         m_strValue = m_strValue.substr(0, m_strValue.size() - 1);
     }
 
-    const MIchar *pFormat = m_bSpaceAfterComma ? "{%s, %s}" : "{%s,%s}";
+    const char *pFormat = m_bSpaceAfterComma ? "{%s, %s}" : "{%s,%s}";
     m_strValue = CMIUtilString::Format(pFormat, m_strValue.c_str(), vResult.GetString().c_str());
 
     return MIstatus::success;
@@ -136,7 +136,7 @@ CMICmnMIValueTuple::BuildTuple(const CMI
     }
 
     const CMIUtilString data(ExtractContentNoBrackets());
-    const MIchar *pFormat = m_bSpaceAfterComma ? "{%s, %s}" : "{%s,%s}";
+    const char *pFormat = m_bSpaceAfterComma ? "{%s, %s}" : "{%s,%s}";
     m_strValue = CMIUtilString::Format(pFormat, data.c_str(), vValue.c_str());
 
     return MIstatus::success;

Modified: lldb/trunk/tools/lldb-mi/MICmnResources.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnResources.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnResources.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnResources.cpp Fri Jul  3 08:45:34 2015
@@ -422,7 +422,7 @@ CMICmnResources::GetStringFromResource(c
 
     const MIuint nRsrcId((*it).first);
     MIunused(nRsrcId);
-    const MIchar *pRsrcData((*it).second);
+    const char *pRsrcData((*it).second);
 
     // Return result
     vrwResourceString = pRsrcData;

Modified: lldb/trunk/tools/lldb-mi/MICmnResources.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnResources.h?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnResources.h (original)
+++ lldb/trunk/tools/lldb-mi/MICmnResources.h Fri Jul  3 08:45:34 2015
@@ -297,8 +297,8 @@ class CMICmnResources : public CMICmnBas
 
     // Typedef:
   private:
-    typedef std::map<MIuint, const MIchar *> MapRscrIdToTextData_t;
-    typedef std::pair<MIuint, const MIchar *> MapPairRscrIdToTextData_t;
+    typedef std::map<MIuint, const char *> MapRscrIdToTextData_t;
+    typedef std::pair<MIuint, const char *> MapPairRscrIdToTextData_t;
 
     // Enumerations:
   private:
@@ -312,7 +312,7 @@ class CMICmnResources : public CMICmnBas
     struct SRsrcTextData
     {
         MIuint id;
-        const MIchar *pTextData;
+        const char *pTextData;
     };
 
     // Methods:

Modified: lldb/trunk/tools/lldb-mi/MICmnStreamStdin.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnStreamStdin.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnStreamStdin.h (original)
+++ lldb/trunk/tools/lldb-mi/MICmnStreamStdin.h Fri Jul  3 08:45:34 2015
@@ -39,7 +39,7 @@ class CMICmnStreamStdin : public CMICmnB
     bool SetPrompt(const CMIUtilString &vNewPrompt);
     void SetEnablePrompt(const bool vbYes);
     bool GetEnablePrompt(void) const;
-    const MIchar *ReadLine(CMIUtilString &vwErrMsg);
+    const char *ReadLine(CMIUtilString &vwErrMsg);
 
     // Methods:
   private:
@@ -57,5 +57,5 @@ class CMICmnStreamStdin : public CMICmnB
     CMIUtilString m_strPromptCurrent; // Command line prompt as shown to the user
     bool m_bShowPrompt;               // True = Yes prompt is shown/output to the user (stdout), false = no prompt
     static const int m_constBufferSize = 2048;
-    MIchar *m_pCmdBuffer;
+    char *m_pCmdBuffer;
 };

Modified: lldb/trunk/tools/lldb-mi/MIDataTypes.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MIDataTypes.h?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MIDataTypes.h (original)
+++ lldb/trunk/tools/lldb-mi/MIDataTypes.h Fri Jul  3 08:45:34 2015
@@ -76,9 +76,6 @@ typedef unsigned int MIuint;
 // Fundamentals:
 typedef float MIflt;
 typedef double MIdbl;
-typedef char MIchar;                 // Defaults to signed char, i.e. MIschar.
-typedef signed char MIschar;         // Range: -128 to 127. More explicit than using MIchar.
-typedef unsigned char MIuchar;       // Range: 0 to 255.
 typedef long long MIint64;           // 64bit signed integer.
 typedef unsigned long long MIuint64; // 64bit unsigned integer.
 

Modified: lldb/trunk/tools/lldb-mi/MIDriver.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MIDriver.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MIDriver.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MIDriver.cpp Fri Jul  3 08:45:34 2015
@@ -559,7 +559,7 @@ CMIDriver::DoMainLoop(void)
     while (bOk && !m_bExitApp)
     {
         CMIUtilString errorText;
-        const MIchar *pCmd = m_rStdin.ReadLine (errorText);
+        const char *pCmd = m_rStdin.ReadLine (errorText);
         if (pCmd != nullptr)
         {
             CMIUtilString lineText(pCmd);
@@ -649,8 +649,8 @@ CMIDriver::InterpretCommandFallThruDrive
     //      errMsg = errMsg.StripCREndOfLine();
     //      errMsg = errMsg.StripCRAll();
     //      const CMIDriverBase * pOtherDriver = GetDriverToFallThruTo();
-    //      const MIchar * pName = pOtherDriver->GetDriverName().c_str();
-    //      const MIchar * pId = pOtherDriver->GetDriverId().c_str();
+    //      const char * pName = pOtherDriver->GetDriverName().c_str();
+    //      const char * pId = pOtherDriver->GetDriverId().c_str();
     //      const CMIUtilString msg( CMIUtilString::Format( MIRSRC( IDS_DRIVER_ERR_FALLTHRU_DRIVER_ERR ), pName, pId, errMsg.c_str() )
     //);
     //      m_pLog->WriteMsg( msg );

Modified: lldb/trunk/tools/lldb-mi/MIDriverMgr.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MIDriverMgr.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MIDriverMgr.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MIDriverMgr.cpp Fri Jul  3 08:45:34 2015
@@ -337,7 +337,7 @@ CMIDriverMgr::DriverParseArgs(const int
     if (!bOk)
     {
         CMIUtilString errMsg;
-        const MIchar *pErrorCstr = error.GetCString();
+        const char *pErrorCstr = error.GetCString();
         if (pErrorCstr != nullptr)
             errMsg = CMIUtilString::Format(MIRSRC(IDS_DRIVER_ERR_PARSE_ARGS), m_pDriverCurrent->GetName().c_str(), pErrorCstr);
         else

Modified: lldb/trunk/tools/lldb-mi/MIUtilDateTimeStd.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MIUtilDateTimeStd.h?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MIUtilDateTimeStd.h (original)
+++ lldb/trunk/tools/lldb-mi/MIUtilDateTimeStd.h Fri Jul  3 08:45:34 2015
@@ -40,5 +40,5 @@ class CMIUtilDateTimeStd
     // Attributes:
   private:
     std::time_t m_rawTime;
-    MIchar m_pScratch[16];
+    char m_pScratch[16];
 };

Modified: lldb/trunk/tools/lldb-mi/MIUtilFileStd.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MIUtilFileStd.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MIUtilFileStd.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MIUtilFileStd.cpp Fri Jul  3 08:45:34 2015
@@ -147,7 +147,7 @@ CMIUtilFileStd::Write(const CMIUtilStrin
 // Throws:  None.
 //--
 bool
-CMIUtilFileStd::Write(const MIchar *vpData, const MIuint vCharCnt)
+CMIUtilFileStd::Write(const char *vpData, const MIuint vCharCnt)
 {
     if (vCharCnt == 0)
         return MIstatus::success;
@@ -273,10 +273,10 @@ CMIUtilFileStd::StripOffFileName(const C
 //          is running on.
 // Type:    Static method.
 // Args:    None.
-// Return:  MIchar - '/' or '\' character.
+// Return:  char - '/' or '\' character.
 // Throws:  None.
 //--
-MIchar
+char
 CMIUtilFileStd::GetSlash(void)
 {
 #if !defined(_MSC_VER)

Modified: lldb/trunk/tools/lldb-mi/MIUtilFileStd.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MIUtilFileStd.h?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MIUtilFileStd.h (original)
+++ lldb/trunk/tools/lldb-mi/MIUtilFileStd.h Fri Jul  3 08:45:34 2015
@@ -23,7 +23,7 @@ class CMIUtilFileStd : public CMICmnBase
 {
     // Static:
   public:
-    static MIchar GetSlash(void);
+    static char GetSlash(void);
 
     // Methods:
   public:
@@ -31,7 +31,7 @@ class CMIUtilFileStd : public CMICmnBase
     //
     bool CreateWrite(const CMIUtilString &vFileNamePath, bool &vwrbNewCreated);
     bool Write(const CMIUtilString &vData);
-    bool Write(const MIchar *vpData, const MIuint vCharCnt);
+    bool Write(const char *vpData, const MIuint vCharCnt);
     void Close(void);
     bool IsOk(void) const;
     bool IsFileExist(const CMIUtilString &vFileNamePath) const;

Modified: lldb/trunk/tools/lldb-mi/MIUtilString.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MIUtilString.cpp?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MIUtilString.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MIUtilString.cpp Fri Jul  3 08:45:34 2015
@@ -37,7 +37,7 @@ CMIUtilString::CMIUtilString(void)
 // Return:  None.
 // Throws:  None.
 //--
-CMIUtilString::CMIUtilString(const MIchar *vpData)
+CMIUtilString::CMIUtilString(const char *vpData)
     : std::string(vpData)
 {
 }
@@ -49,7 +49,7 @@ CMIUtilString::CMIUtilString(const MIcha
 // Return:  None.
 // Throws:  None.
 //--
-CMIUtilString::CMIUtilString(const MIchar *const *vpData)
+CMIUtilString::CMIUtilString(const char *const *vpData)
     : std::string((const char *)vpData)
 {
 }
@@ -61,7 +61,7 @@ CMIUtilString::CMIUtilString(const MIcha
 // Return:  CMIUtilString & - *this string.
 // Throws:  None.
 //--
-CMIUtilString &CMIUtilString::operator=(const MIchar *vpRhs)
+CMIUtilString &CMIUtilString::operator=(const char *vpRhs)
 {
     if (*this == vpRhs)
         return *this;
@@ -480,7 +480,7 @@ CMIUtilString::ExtractNumberFromHexadeci
 // Throws:  None.
 //--
 bool
-CMIUtilString::IsAllValidAlphaAndNumeric(const MIchar *vpText)
+CMIUtilString::IsAllValidAlphaAndNumeric(const char *vpText)
 {
     const MIuint len = ::strlen(vpText);
     if (len == 0)
@@ -488,7 +488,7 @@ CMIUtilString::IsAllValidAlphaAndNumeric
 
     for (MIuint i = 0; i < len; i++, vpText++)
     {
-        const MIchar c = *vpText;
+        const char c = *vpText;
         if (::isalnum((int)c) == 0)
             return false;
     }
@@ -525,7 +525,7 @@ CMIUtilString
 CMIUtilString::Trim(void) const
 {
     CMIUtilString strNew(*this);
-    const MIchar *pWhiteSpace = " \t\n\v\f\r";
+    const char *pWhiteSpace = " \t\n\v\f\r";
     const MIint nPos = find_last_not_of(pWhiteSpace);
     if (nPos != (MIint)std::string::npos)
     {
@@ -548,7 +548,7 @@ CMIUtilString::Trim(void) const
 // Throws:  None.
 //--
 CMIUtilString
-CMIUtilString::Trim(const MIchar vChar) const
+CMIUtilString::Trim(const char vChar) const
 {
     CMIUtilString strNew(*this);
     const MIint nLen = strNew.length();
@@ -584,7 +584,7 @@ CMIUtilString::FormatBinary(const MIuint
         nNum = nNum >> 1;
         nLen++;
     }
-    MIchar pN[nConstBits + 1];
+    char pN[nConstBits + 1];
     MIuint j = 0;
     for (i = nLen; i > 0; --i, j++)
     {
@@ -606,7 +606,7 @@ CMIUtilString::FormatBinary(const MIuint
 // Throws:  None.
 //--
 CMIUtilString
-CMIUtilString::RemoveRepeatedCharacters(const MIchar vChar)
+CMIUtilString::RemoveRepeatedCharacters(const char vChar)
 {
     return RemoveRepeatedCharacters(0, vChar);
 }
@@ -622,9 +622,9 @@ CMIUtilString::RemoveRepeatedCharacters(
 // Throws:  None.
 //--
 CMIUtilString
-CMIUtilString::RemoveRepeatedCharacters(const MIint vnPos, const MIchar vChar)
+CMIUtilString::RemoveRepeatedCharacters(const MIint vnPos, const char vChar)
 {
-    const MIchar cQuote = '"';
+    const char cQuote = '"';
 
     // Look for first quote of two
     MIint nPos = find(cQuote, vnPos);
@@ -654,7 +654,7 @@ CMIUtilString::RemoveRepeatedCharacters(
 bool
 CMIUtilString::IsQuoted(void) const
 {
-    const MIchar cQuote = '"';
+    const char cQuote = '"';
 
     if (at(0) != cQuote)
         return false;
@@ -763,8 +763,8 @@ CMIUtilString::FindFirstNot(const CMIUti
 MIuint
 CMIUtilString::FindFirstQuote(const MIuint vnPos) const
 {
-    const MIchar cBckSlash('\\');
-    const MIchar cQuote('"');
+    const char cBckSlash('\\');
+    const char cQuote('"');
     const MIuint nLen(length());
 
     MIuint nPos = vnPos;
@@ -801,7 +801,7 @@ CMIUtilString::Escape(const bool vbEscap
     strNew.reserve(nLen);
     for (MIuint nIndex(0); nIndex < nLen; ++nIndex)
     {
-        const MIchar cUnescapedChar((*this)[nIndex]);
+        const char cUnescapedChar((*this)[nIndex]);
         if (cUnescapedChar == '"' && vbEscapeQuotes)
             strNew.append("\\\"");
         else
@@ -821,7 +821,7 @@ CMIUtilString::Escape(const bool vbEscap
 CMIUtilString
 CMIUtilString::AddSlashes(void) const
 {
-    const MIchar cBckSlash('\\');
+    const char cBckSlash('\\');
     const MIuint nLen(length());
     CMIUtilString strNew;
     strNew.reserve(nLen);
@@ -840,7 +840,7 @@ CMIUtilString::AddSlashes(void) const
         const MIuint nAppendLen(nUnescapedCharPos - nOffset);
         strNew.append(*this, nOffset, nAppendLen);
         strNew.push_back(cBckSlash);
-        const MIchar cUnescapedChar((*this)[nUnescapedCharPos]);
+        const char cUnescapedChar((*this)[nUnescapedCharPos]);
         strNew.push_back(cUnescapedChar);
         nOffset = nUnescapedCharPos + 1;
     }
@@ -858,7 +858,7 @@ CMIUtilString::AddSlashes(void) const
 CMIUtilString
 CMIUtilString::StripSlashes(void) const
 {
-    const MIchar cBckSlash('\\');
+    const char cBckSlash('\\');
     const MIuint nLen(length());
     CMIUtilString strNew;
     strNew.reserve(nLen);
@@ -882,7 +882,7 @@ CMIUtilString::StripSlashes(void) const
             strNew.push_back(cBckSlash);
             break;
         }
-        const MIchar cEscapedChar((*this)[nBckSlashPos + 1]);
+        const char cEscapedChar((*this)[nBckSlashPos + 1]);
         const MIuint nEscapedCharPos(std::string("\"\\").find(cEscapedChar));
         const bool bEscapedCharNotFound(nEscapedCharPos == (MIuint)std::string::npos);
         if (bEscapedCharNotFound)

Modified: lldb/trunk/tools/lldb-mi/MIUtilString.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MIUtilString.h?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MIUtilString.h (original)
+++ lldb/trunk/tools/lldb-mi/MIUtilString.h Fri Jul  3 08:45:34 2015
@@ -35,7 +35,7 @@ class CMIUtilString : public std::string
     static CMIUtilString Format(const CMIUtilString vFormating, ...);
     static CMIUtilString FormatBinary(const MIuint64 vnDecimal);
     static CMIUtilString FormatValist(const CMIUtilString &vrFormating, va_list vArgs);
-    static bool IsAllValidAlphaAndNumeric(const MIchar *vpText);
+    static bool IsAllValidAlphaAndNumeric(const char *vpText);
     static bool Compare(const CMIUtilString &vrLhs, const CMIUtilString &vrRhs);
     static CMIUtilString ConvertToPrintableASCII(const char vChar);
     static CMIUtilString ConvertToPrintableASCII(const char16_t vChar16);
@@ -44,22 +44,22 @@ class CMIUtilString : public std::string
     // Methods:
   public:
     /* ctor */ CMIUtilString(void);
-    /* ctor */ CMIUtilString(const MIchar *vpData);
-    /* ctor */ CMIUtilString(const MIchar *const *vpData);
+    /* ctor */ CMIUtilString(const char *vpData);
+    /* ctor */ CMIUtilString(const char *const *vpData);
     //
     bool ExtractNumber(MIint64 &vwrNumber) const;
     CMIUtilString FindAndReplace(const CMIUtilString &vFind, const CMIUtilString &vReplaceWith) const;
     bool IsNumber(void) const;
     bool IsHexadecimalNumber(void) const;
     bool IsQuoted(void) const;
-    CMIUtilString RemoveRepeatedCharacters(const MIchar vChar);
+    CMIUtilString RemoveRepeatedCharacters(const char vChar);
     MIuint Split(const CMIUtilString &vDelimiter, VecString_t &vwVecSplits) const;
     MIuint SplitConsiderQuotes(const CMIUtilString &vDelimiter, VecString_t &vwVecSplits) const;
     MIuint SplitLines(VecString_t &vwVecSplits) const;
     CMIUtilString StripCREndOfLine(void) const;
     CMIUtilString StripCRAll(void) const;
     CMIUtilString Trim(void) const;
-    CMIUtilString Trim(const MIchar vChar) const;
+    CMIUtilString Trim(const char vChar) const;
     MIuint FindFirst(const CMIUtilString &vrPattern, const MIuint vnPos = 0) const;
     MIuint FindFirst(const CMIUtilString &vrPattern, const bool vbSkipQuotedText, bool &vrwbNotFoundClosedQuote,
                      const MIuint vnPos = 0) const;
@@ -68,7 +68,7 @@ class CMIUtilString : public std::string
     CMIUtilString AddSlashes(void) const;
     CMIUtilString StripSlashes(void) const;
     //
-    CMIUtilString &operator=(const MIchar *vpRhs);
+    CMIUtilString &operator=(const char *vpRhs);
     CMIUtilString &operator=(const std::string &vrRhs);
 
     // Overrideable:
@@ -82,6 +82,6 @@ class CMIUtilString : public std::string
     // Methods:
   private:
     bool ExtractNumberFromHexadecimal(MIint64 &vwrNumber) const;
-    CMIUtilString RemoveRepeatedCharacters(const MIint vnPos, const MIchar vChar);
+    CMIUtilString RemoveRepeatedCharacters(const MIint vnPos, const char vChar);
     MIuint FindFirstQuote(const MIuint vnPos) const;
 };





More information about the lldb-commits mailing list
--- lldb/trunk/tools/lldb-mi/MICmnStreamStdin.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnStreamStdin.cpp Fri Jul  3 08:45:34 2015
@@ -72,7 +72,7 @@ CMICmnStreamStdin::Initialize(void)
 
     if (bOk)
     {
-        m_pCmdBuffer = new MIchar[m_constBufferSize];
+        m_pCmdBuffer = new char[m_constBufferSize];
     }
     else
     {
@@ -198,16 +198,16 @@ CMICmnStreamStdin::GetEnablePrompt(void)
 // Details: Wait on new line of data from stdin stream (completed by '\n' or '\r').
 // Type:    Method.
 // Args:    vwErrMsg    - (W) Empty string ok or error description.
 // Return:  MIchar * - text buffer pointer or NULL on failure.
 // Throws:  None.
 //--
-const MIchar *
+const char *
 CMICmnStreamStdin::ReadLine(CMIUtilString &vwErrMsg)
 {
     vwErrMsg.clear();
 
     // Read user input
-    const MIchar *pText = ::fgets(&m_pCmdBuffer[0], m_constBufferSize, stdin);
+    const char *pText = ::fgets(&m_pCmdBuffer[0], m_constBufferSize, stdin);
     if (pText == nullptr)
     {
 #ifdef _MSC_VER
@@ -228,7 +228,7 @@ CMICmnStreamStdin::ReadLine(CMIUtilStrin
     }
 
     // Strip off new line characters
-    for (MIchar *pI = m_pCmdBuffer; *pI != '\0'; pI++)
+    for (char *pI = m_pCmdBuffer; *pI != '\0'; pI++)
     {
         if ((*pI == '\n') || (*pI == '\r'))
         {
@@ -198,16 +198,16 @@ CMICmnStreamStdin::GetEnablePrompt(void)
 // Type:    Method.
 // Args:    vwErrMsg    - (W) Empty string ok or error description.
-// Return:  MIchar * - text buffer pointer or NULL on failure.
+// Return:  char * - text buffer pointer or NULL on failure.
 // Throws:  None.
 //--

Modified: lldb/trunk/tools/lldb-mi/MICmnStreamStdin.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnStreamStdin.h?rev=241349&r1=241348&r2=241349&view=diff
==============================================================================